@@ -85,3 +85,5 @@ main = hspec $ do
       sanitizedB "<img><hr/>" "<img><hr />"
     it "removes closing voids" $ do
       sanitizedB "<img></img>" "<img />"
+    it "interleaved" $
+      sanitizedB "<i>hello<b>world</i>" "<i>hello<b>world<i></i></b></i>"
